@@ -16,7 +16,6 @@ import pandas as pd
 import scipy.stats as stats
 from libpysal.weights import W
 from libpysal.weights.spatial_lag import lag_spatial
-from matplotlib import colors
 from scipy import sparse
 
 from .crand import _prepare_univariate
@@ -33,6 +32,7 @@ __all__ = [
     "Moran_Local_BV",
     "Moran_Rate",
     "Moran_Local_Rate",
+    "plot_moran_facet",
 ]
 
 PERMUTATIONS = 999
@@ -68,7 +68,8 @@ class Moran:
     transformation  : string
                       weights transformation,  default is row-standardized "r".
                       Other options include "B": binary,  "D":
-                      doubly-standardized,  "U": untransformed
+                      doubly-standardized,  "O": restore original transformation 
+                      (applicable only if ``w`` is  passed as ``W``)
                       (general weights), "V": variance-stabilizing.
     permutations    : int
                       number of random permutations for calculation of
@@ -83,6 +84,8 @@ class Moran:
                    original variable
     w            : W | Graph
                    original w object
+    z            : array
+                   zero-mean, unit standard deviation normalized y
     permutations : int
                    number of permutations
     I            : float
@@ -156,6 +159,7 @@ class Moran:
     0.00027147862770937614
 
     SIDS example replicating OpenGeoda
+
     >>> w = libpysal.io.open(libpysal.examples.get_path("sids2.gal")).read()
     >>> f = libpysal.io.open(libpysal.examples.get_path("sids2.dbf"))
     >>> SIDR = np.array(f.by_col("SIDR74"))
@@ -319,6 +323,89 @@ class Moran:
             **stat_kws,
         )
 
+    def plot_scatter(
+        self,
+        ax=None,
+        scatter_kwds=None,
+        fitline_kwds=None,
+    ):
+        """
+        Plot a Moran scatterplot with optional coloring for significant points.
+
+        Parameters
+        ----------
+        ax : matplotlib.axes.Axes, optional
+            Pre-existing axes for the plot, by default None.
+        scatter_kwds : dict, optional
+            Additional keyword arguments for scatter plot, by default None.
+        fitline_kwds : dict, optional
+            Additional keyword arguments for fit line, by default None.
+
+        Returns
+        -------
+        matplotlib.axes.Axes
+            Axes object with the Moran scatterplot.
+        """
+        return _scatterplot(
+            self,
+            crit_value=None,
+            ax=ax,
+            scatter_kwds=scatter_kwds,
+            fitline_kwds=fitline_kwds,
+        )
+
+    def plot_simulation(self, ax=None, legend=False, fitline_kwds=None, **kwargs):
+        """
+        Global Moran's I simulated reference distribution.
+
+        Parameters
+        ----------
+        ax : matplotlib.axes.Axes, optional
+            Pre-existing axes for the plot, by default None.
+        legend : bool, optional
+            Plot a legend, by default False
+        fitline_kwds : dict, optional
+            Additional keyword arguments for vertical Moran fit line, by default None.
+        **kwargs : keyword arguments, optional
+            Additional keyword arguments for KDE plot passed to ``seaborn.kdeplot``,
+            by default None.
+
+        Returns
+        -------
+        matplotlib.axes.Axes
+            Axes object with the Moran scatterplot.
+
+        Notes
+        -----
+        This requires optional dependencies ``matplotlib`` and ``seaborn``.
+
+        Examples
+        --------
+        >>> import libpysal
+        >>> w = libpysal.io.open(libpysal.examples.get_path("stl.gal")).read()
+        >>> f = libpysal.io.open(libpysal.examples.get_path("stl_hom.txt"))
+        >>> y = np.array(f.by_col['HR8893'])
+        >>> from esda.moran import Moran
+        >>> mi = Moran(y,  w)
+
+        Default plot:
+
+        >>> mi.plot_simulation()
+
+        Customized styling that turns the distribution into a pink line and line
+        indicating I to a black line:
+
+        >>> mi.plot_simulation(fitline_kwds={"color": "k"}, color="pink", shade=False)
+        """
+        return _simulation_plot(
+            self,
+            ax=ax,
+            legend=legend,
+            bivariate=False,
+            fitline_kwds=fitline_kwds,
+            **kwargs,
+        )
+
 
 class Moran_BV:  # noqa: N801
     """
@@ -337,7 +424,7 @@ class Moran_BV:  # noqa: N801
                       Other options include
                       "B": binary,
                       "D": doubly-standardized,
-                      "U": untransformed (general weights),
+                      "O": restore original transformation (applicable only if ``w`` is  passed as ``W``),
                       "V": variance-stabilizing.
     permutations    : int
                       number of random permutations for calculation of pseudo
@@ -532,6 +619,72 @@ class Moran_BV:  # noqa: N801
             **stat_kws,
         )
 
+    def plot_scatter(
+        self,
+        ax=None,
+        scatter_kwds=None,
+        fitline_kwds=None,
+    ):
+        """
+        Plot a Moran scatterplot with optional coloring for significant points.
+
+        Parameters
+        ----------
+        ax : matplotlib.axes.Axes, optional
+            Pre-existing axes for the plot, by default None.
+        scatter_kwds : dict, optional
+            Additional keyword arguments for scatter plot, by default None.
+        fitline_kwds : dict, optional
+            Additional keyword arguments for fit line, by default None.
+
+        Returns
+        -------
+        matplotlib.axes.Axes
+            Axes object with the Moran scatterplot.
+        """
+        return _scatterplot(
+            self,
+            crit_value=None,
+            bivariate=True,
+            ax=ax,
+            scatter_kwds=scatter_kwds,
+            fitline_kwds=fitline_kwds,
+        )
+
+    def plot_simulation(self, ax=None, legend=False, fitline_kwds=None, **kwargs):
+        """
+        Global Moran's I simulated reference distribution.
+
+        Parameters
+        ----------
+        ax : matplotlib.axes.Axes, optional
+            Pre-existing axes for the plot, by default None.
+        legend : bool, optional
+            Plot a legend, by default False
+        fitline_kwds : dict, optional
+            Additional keyword arguments for vertical Moran fit line, by default None.
+        **kwargs : keyword arguments, optional
+            Additional keyword arguments for KDE plot passed to ``seaborn.kdeplot``,
+            by default None.
+
+        Returns
+        -------
+        matplotlib.axes.Axes
+            Axes object with the Moran scatterplot.
+
+        Notes
+        -----
+        This requires optional dependencies ``matplotlib`` and ``seaborn``.
+        """
+        return _simulation_plot(
+            self,
+            ax=ax,
+            legend=legend,
+            bivariate=True,
+            fitline_kwds=fitline_kwds,
+            **kwargs,
+        )
+
 
 def Moran_BV_matrix(variables, w, permutations=0, varnames=None):  # noqa: N802
     """
@@ -632,6 +785,115 @@ def _Moran_BV_Matrix_array(variables, w, permutations=0, varnames=None):  # noqa
     return results
 
 
+def plot_moran_facet(
+    moran_matrix,
+    figsize=(16, 12),
+    scatter_bv_kwds=None,
+    fitline_bv_kwds=None,
+    scatter_glob_kwds=dict(color="#737373"),
+    fitline_glob_kwds=None,
+):
+    """
+    Moran Facet visualization.
+
+    A matrix containing bivariate Moran plots between all pairs of variables present in
+    the ``moran_matrix`` dictionary. On the diagonal contains global Moran plot.
+
+    Parameters
+    ----------
+    moran_matrix : dict
+        Dictionary of Moran_BV objects returned by Moran_BV_matrix
+    figsize : tuple, optional
+        Size of the figure. Default is (16,12)
+    scatter_bv_kwds : keyword arguments, optional
+        Keywords used for creating and designing the scatter points of
+        off-diagonal Moran_BV plots.
+        Default =None.
+    fitline_bv_kwds : keyword arguments, optional
+        Keywords used for creating and designing the moran fitline of
+        off-diagonal Moran_BV plots.
+        Default =None.
+    scatter_glob_kwds : keyword arguments, optional
+        Keywords used for creating and designing the scatter points of
+        diagonal Moran plots.
+        Default =None.
+    fitline_glob_kwds : keyword arguments, optional
+        Keywords used for creating and designing the moran fitline of
+        diagonal Moran plots.
+        Default =None.
+
+    Returns
+    -------
+    ax : matplotlib Axes instance
+        Axes in which the figure is plotted
+    """
+    try:
+        from matplotlib import pyplot as plt
+    except ImportError as err:
+        raise ImportError(
+            "matplotlib must be installed to plot the simulation."
+        ) from err
+
+    nrows = int(np.sqrt(len(moran_matrix))) + 1
+    ncols = nrows
+
+    fig, axarr = plt.subplots(nrows, ncols, figsize=figsize, sharey=True, sharex=True)
+    fig.suptitle("Moran Facet")
+
+    for row in range(nrows):
+        for col in range(ncols):
+            if row == col:
+                global_m = Moran(
+                    moran_matrix[row, (row + 1) % 4].zy,
+                    moran_matrix[row, (row + 1) % 4].w,
+                )
+                _scatterplot(
+                    global_m,
+                    crit_value=None,
+                    ax=axarr[row, col],
+                    scatter_kwds=scatter_glob_kwds,
+                    fitline_kwds=fitline_glob_kwds,
+                )
+                axarr[row, col].set_facecolor("#d9d9d9")
+            else:
+                _scatterplot(
+                    moran_matrix[row, col],
+                    bivariate=True,
+                    crit_value=None,
+                    ax=axarr[row, col],
+                    scatter_kwds=scatter_bv_kwds,
+                    fitline_kwds=fitline_bv_kwds,
+                )
+
+            axarr[row, col].spines[["left", "right", "top", "bottom"]].set_visible(
+                False
+            )
+            if row == nrows - 1:
+                axarr[row, col].set_xlabel(
+                    str(moran_matrix[(col + 1) % 4, col].varnames["x"]).format(col)
+                )
+                axarr[row, col].spines["bottom"].set_visible(True)
+            else:
+                axarr[row, col].set_xlabel("")
+
+            if col == 0:
+                axarr[row, col].set_ylabel(
+                    (
+                        "Spatial Lag of "
+                        + str(moran_matrix[row, (row + 1) % 4].varnames["y"])
+                    ).format(row)
+                )
+                axarr[row, col].spines["left"].set_visible(True)
+            else:
+                axarr[row, col].set_ylabel("")
+
+            axarr[row, col].set_title("")
+
+    plt.tight_layout()
+
+    return axarr
+
+
 class Moran_Rate(Moran):  # noqa: N801
     """
     Adjusted Moran's I Global Autocorrelation Statistic for Rate
@@ -655,7 +917,7 @@ class Moran_Rate(Moran):  # noqa: N801
                       Other options include
                       "B": binary,
                       "D": doubly-standardized,
-                      "U": untransformed (general weights),
+                      "O": restore original transformation (applicable only if ``w`` is  passed as ``W``),
                       "V": variance-stabilizing.
     two_tailed      : boolean
                       If True (default), analytical p-values for Moran's I are
@@ -670,6 +932,8 @@ class Moran_Rate(Moran):  # noqa: N801
                    rate variable computed from parameters e and b
                    if adjusted is True, y is standardized rates
                    otherwise, y is raw rates
+    z            : array
+                   zero-mean, unit standard deviation normalized y
     w            : W | Graph
                    original w object
     permutations : int
@@ -889,7 +1153,7 @@ class Moran_Local:  # noqa: N801
          Other options include
          "B": binary,
          "D": doubly-standardized,
-         "U": untransformed (general weights),
+         "O": restore original transformation (applicable only if ``w`` is  passed as ``W``),
          "V": variance-stabilizing.
     permutations : int
         number of random permutations for calculation of pseudo
@@ -923,6 +1187,8 @@ class Moran_Local:  # noqa: N801
         original variable
     w : W | Graph
         original w object
+    z : array
+        zero-mean, unit standard deviation normalized y
     permutations : int
         number of random permutations for calculation of pseudo p_values
     Is : array
@@ -1243,7 +1509,142 @@ class Moran_Local:  # noqa: N801
         """
         gdf = gdf.copy()
         gdf["Moran Cluster"] = self.get_cluster_labels(crit_value)
-        return _explore_local_moran(self, gdf, crit_value, **kwargs)
+        return _viz_local_moran(self, gdf, crit_value, "explore", **kwargs)
+
+    def plot(self, gdf, crit_value=0.05, **kwargs):
+        """Create static map of LISA indicators
+
+        Parameters
+        ----------
+        gdf : geopandas.GeoDataFrame
+            geodataframe used to conduct the local Moran analysis
+        crit_value : float, optional
+            critical value to determine statistical significance, by default 0.05
+        kwargs : dict, optional
+            additional keyword arguments passed to the geopandas `explore` method
+
+        Returns
+        -------
+        ax
+            matplotlib axis
+        """
+        gdf = gdf.copy()
+        gdf["Moran Cluster"] = self.get_cluster_labels(crit_value)
+        return _viz_local_moran(self, gdf, crit_value, "plot", **kwargs)
+
+    def plot_scatter(
+        self,
+        crit_value=0.05,
+        ax=None,
+        scatter_kwds=None,
+        fitline_kwds=None,
+    ):
+        """
+        Plot a Moran scatterplot with optional coloring for significant points.
+
+        Parameters
+        ----------
+        crit_value : float, optional
+            Critical value to determine statistical significance, by default 0.05.
+        ax : matplotlib.axes.Axes, optional
+            Pre-existing axes for the plot, by default None.
+        scatter_kwds : dict, optional
+            Additional keyword arguments for scatter plot, by default None.
+        fitline_kwds : dict, optional
+            Additional keyword arguments for fit line, by default None.
+
+        Returns
+        -------
+        matplotlib.axes.Axes
+            Axes object with the Moran scatterplot.
+        """
+        return _scatterplot(
+            self,
+            crit_value=crit_value,
+            ax=ax,
+            scatter_kwds=scatter_kwds,
+            fitline_kwds=fitline_kwds,
+        )
+
+    def plot_combination(
+        self,
+        gdf,
+        attribute,
+        crit_value=0.05,
+        region_column=None,
+        mask=None,
+        mask_color="#636363",
+        quadrant=None,
+        legend=True,
+        scheme="Quantiles",
+        cmap="YlGnBu",
+        figsize=(15, 4),
+        scatter_kwds=None,
+        fitline_kwds=None,
+        legend_kwds=None,
+    ):
+        """
+        Produce three-plot visualisation of Moran Scatteprlot, LISA cluster
+        and Choropleth maps, with Local Moran region and quadrant masking
+
+        Parameters
+        ----------
+        gdf : geopandas.GeoDataFrame
+            geodataframe used to conduct the local Moran analysis
+        attribute : str
+            Column name of attribute which should be depicted in Choropleth map.
+        crit_value : float, optional
+            critical value to determine statistical significance, by default 0.05
+        region_column: string, optional
+            Column name containing mask region of interest, by default None
+        mask: str, float, int, optional
+            Identifier or name of the region to highlight, by default None
+            Use the same dtype to specifiy as in original dataset.
+        mask_color: str, optional
+            Color of mask, by default '#636363'.
+        quadrant : int, optional
+            Quadrant 1-4 in scatterplot masking values in LISA cluster and
+            Choropleth maps, by default None
+        figsize: tuple, optional
+            W, h of figure, by default (15,4)
+        legend: boolean, optional
+            If True, legend for maps will be depicted, by default True
+        scheme: str, optional
+            Name of mapclassify classifier to be used, by default 'Quantiles'
+        cmap: str, optional
+            Name of matplotlib colormap used for plotting the Choropleth.
+            By default 'YlGnBu'.
+        scatter_kwds : keyword arguments, optional
+            Keywords used for creating and designing the scatter points, by default
+            None.
+        fitline_kwds : keyword arguments, optional
+            Keywords used for creating and designing the moran fitline
+            in the scatterplot, by default None.
+        legend_kwds : dict
+            Keyword arguments passed to geopandas.GeodataFrame.plot ``legend_kwds``
+            allowing repositioning of the legend in LISA cluster plot and choropleth.
+
+        Returns
+        -------
+        axs : array of Matplotlib axes
+        """
+        return _plot_combination(
+            self,
+            gdf,
+            attribute,
+            crit_value=crit_value,
+            region_column=region_column,
+            mask=mask,
+            mask_color=mask_color,
+            quadrant=quadrant,
+            legend=legend,
+            scheme=scheme,
+            cmap=cmap,
+            figsize=figsize,
+            scatter_kwds=scatter_kwds,
+            fitline_kwds=fitline_kwds,
+            legend_kwds=legend_kwds,
+        )
 
 
 class Moran_Local_BV:  # noqa: N801
@@ -1263,7 +1664,7 @@ class Moran_Local_BV:  # noqa: N801
         Other options include
         "B": binary,
         "D": doubly-standardized,
-        "U": untransformed (general weights),
+        "O": restore original transformation (applicable only if ``w`` is  passed as ``W``),
         "V": variance-stabilizing.
     permutations   : int
         number of random permutations for calculation of pseudo
@@ -1512,6 +1913,179 @@ class Moran_Local_BV:  # noqa: N801
             **stat_kws,
         )
 
+    def get_cluster_labels(self, crit_value=0.05):
+        """Return LISA cluster labels for each observation.
+
+        Parameters
+        ----------
+        crit_value : float, optional
+            crititical significance value for statistical inference, by default 0.05
+
+        Returns
+        -------
+        numpy.array
+            an array of cluster labels aligned with the input data used to conduct the
+            local Moran analysis
+        """
+        return _get_cluster_labels(self, crit_value)
+
+    def explore(self, gdf, crit_value=0.05, **kwargs):
+        """Create interactive map of LISA indicators
+
+        Parameters
+        ----------
+        gdf : geopandas.GeoDataFrame
+            geodataframe used to conduct the local Moran analysis
+        crit_value : float, optional
+            critical value to determine statistical significance, by default 0.05
+        kwargs : dict, optional
+            additional keyword arguments passed to the geopandas `explore` method
+
+        Returns
+        -------
+        Folium.Map
+            interactive map with LISA clusters
+        """
+        gdf = gdf.copy()
+        gdf["Moran Cluster"] = self.get_cluster_labels(crit_value)
+        return _viz_local_moran(self, gdf, crit_value, "explore", **kwargs)
+
+    def plot(self, gdf, crit_value=0.05, **kwargs):
+        """Create static map of LISA indicators
+
+        Parameters
+        ----------
+        gdf : geopandas.GeoDataFrame
+            geodataframe used to conduct the local Moran analysis
+        crit_value : float, optional
+            critical value to determine statistical significance, by default 0.05
+        kwargs : dict, optional
+            additional keyword arguments passed to the geopandas `explore` method
+
+        Returns
+        -------
+        ax
+            matplotlib axis
+        """
+        gdf = gdf.copy()
+        gdf["Moran Cluster"] = self.get_cluster_labels(crit_value)
+        return _viz_local_moran(self, gdf, crit_value, "plot", **kwargs)
+
+    def plot_scatter(
+        self,
+        crit_value=0.05,
+        ax=None,
+        scatter_kwds=None,
+        fitline_kwds=None,
+    ):
+        """
+        Plot a Moran scatterplot with optional coloring for significant points.
+
+        Parameters
+        ----------
+        crit_value : float, optional
+            Critical value to determine statistical significance, by default 0.05.
+        ax : matplotlib.axes.Axes, optional
+            Pre-existing axes for the plot, by default None.
+        scatter_kwds : dict, optional
+            Additional keyword arguments for scatter plot, by default None.
+        fitline_kwds : dict, optional
+            Additional keyword arguments for fit line, by default None.
+
+        Returns
+        -------
+        matplotlib.axes.Axes
+            Axes object with the Moran scatterplot.
+        """
+        return _scatterplot(
+            self,
+            crit_value=crit_value,
+            bivariate=True,
+            ax=ax,
+            scatter_kwds=scatter_kwds,
+            fitline_kwds=fitline_kwds,
+        )
+
+    def plot_combination(
+        self,
+        gdf,
+        attribute,
+        crit_value=0.05,
+        region_column=None,
+        mask=None,
+        mask_color="#636363",
+        quadrant=None,
+        legend=True,
+        scheme="Quantiles",
+        cmap="YlGnBu",
+        figsize=(15, 4),
+        scatter_kwds=None,
+        fitline_kwds=None,
+        legend_kwds=None,
+    ):
+        """
+        Produce three-plot visualisation of Moran Scatteprlot, LISA cluster
+        and Choropleth maps, with Local Moran region and quadrant masking
+
+        Parameters
+        ----------
+        gdf : geopandas.GeoDataFrame
+            geodataframe used to conduct the local Moran analysis
+        attribute : str
+            Column name of attribute which should be depicted in Choropleth map.
+        crit_value : float, optional
+            critical value to determine statistical significance, by default 0.05
+        region_column: string, optional
+            Column name containing mask region of interest, by default None
+        mask: str, float, int, optional
+            Identifier or name of the region to highlight, by default None
+            Use the same dtype to specifiy as in original dataset.
+        mask_color: str, optional
+            Color of mask, by default '#636363'.
+        quadrant : int, optional
+            Quadrant 1-4 in scatterplot masking values in LISA cluster and
+            Choropleth maps, by default None
+        figsize: tuple, optional
+            W, h of figure, by default (15,4)
+        legend: boolean, optional
+            If True, legend for maps will be depicted, by default True
+        scheme: str, optional
+            Name of mapclassify classifier to be used, by default 'Quantiles'
+        cmap: str, optional
+            Name of matplotlib colormap used for plotting the Choropleth.
+            By default 'YlGnBu'.
+        scatter_kwds : keyword arguments, optional
+            Keywords used for creating and designing the scatter points, by default
+            None.
+        fitline_kwds : keyword arguments, optional
+            Keywords used for creating and designing the moran fitline
+            in the scatterplot, by default None.
+        legend_kwds : dict
+            Keyword arguments passed to geopandas.GeodataFrame.plot ``legend_kwds``
+            allowing repositioning of the legend in LISA cluster plot and choropleth.
+
+        Returns
+        -------
+        axs : array of Matplotlib axes
+        """
+        return _plot_combination(
+            self,
+            gdf,
+            attribute,
+            crit_value=crit_value,
+            region_column=region_column,
+            mask=mask,
+            mask_color=mask_color,
+            quadrant=quadrant,
+            legend=legend,
+            scheme=scheme,
+            cmap=cmap,
+            figsize=figsize,
+            scatter_kwds=scatter_kwds,
+            fitline_kwds=fitline_kwds,
+            legend_kwds=legend_kwds,
+        )
+
 
 class Moran_Local_Rate(Moran_Local):  # noqa: N801
     """
@@ -1533,7 +2107,7 @@ class Moran_Local_Rate(Moran_Local):  # noqa: N801
         Other options include
         "B": binary,
         "D": doubly-standardized,
-        "U": untransformed (general weights),
+        "O": restore original transformation (applicable only if ``w`` is  passed as ``W``),
         "V": variance-stabilizing.
     permutations : int
         number of random permutations for calculation of pseudo
@@ -1564,6 +2138,8 @@ class Moran_Local_Rate(Moran_Local):  # noqa: N801
         rate variables computed from parameters e and b
         if adjusted is True, y is standardized rates
         otherwise, y is raw rates
+    z : array
+        zero-mean, unit standard deviation normalized y
     w : W | Graph
         original w object
     permutations : int
@@ -1765,8 +2341,8 @@ class Moran_Local_Rate(Moran_Local):  # noqa: N801
             df[col] = rate_df[col]
 
 
-def _explore_local_moran(moran_local, gdf, crit_value, **kwargs):
-    """Plot local Moran values as an interactive map
+def _viz_local_moran(moran_local, gdf, crit_value, method, **kwargs):
+    """Common helper for local Moran's I vizualization
 
     Parameters
     ----------
@@ -1776,16 +2352,25 @@ def _explore_local_moran(moran_local, gdf, crit_value, **kwargs):
         geodataframe used to create the Moran_Local class
     crit_value : float, optional
         critical value for determining statistical significance, by default 0.05
+    method : str {"explore", "plot"}
+        GeoDataFrame method to be used
     kwargs : dict, optional
         additional keyword arguments are passed directly
-        to geopandas.explore, by default None
+        to the plotting method, by default None
 
     Returns
     -------
-    m
-        folium.Map
+    m | ax
+        either folium.Map or maptlotlib.Axes
     """
 
+    try:
+        from matplotlib import colors
+    except ImportError as err:
+        raise ImportError(
+            "matplotlib library must be installed to use the vizualization feature"
+        ) from err
+
     gdf = gdf.copy()
     gdf["Moran Cluster"] = moran_local.get_cluster_labels(crit_value)
     gdf["p-value"] = moran_local.p_sim
@@ -1804,8 +2389,9 @@ def _explore_local_moran(moran_local, gdf, crit_value, **kwargs):
     if "cmap" not in kwargs:
         kwargs["cmap"] = hmap
 
-    m = gdf[["Moran Cluster", "p-value", "geometry"]].explore("Moran Cluster", **kwargs)
-    return m
+    return getattr(gdf[["Moran Cluster", "p-value", "geometry"]], method)(
+        "Moran Cluster", **kwargs
+    )
 
 
 def _get_cluster_labels(moran_local, crit_value):
@@ -1824,6 +2410,355 @@ def _get_cluster_labels(moran_local, crit_value):
     return gdf["Moran Cluster"].values
 
 
+def _scatterplot(
+    moran,
+    crit_value=0.05,
+    bivariate=False,
+    ax=None,
+    scatter_kwds=None,
+    fitline_kwds=None,
+):
+    """Generates a Moran Local or Global Scatterplot.
+
+    Parameters
+    ----------
+    moran : Moran object
+        An instance of a Moran or Moran_Local object.
+    crit_value : float, optional
+        The critical value for significance. Default is 0.05.
+    ax : matplotlib.axes.Axes, optional
+        The axes on which to draw the plot. If None, a new figure and axes are created.
+    scatter_kwds : dict, optional
+        Additional keyword arguments to pass to the scatter plot.
+    fitline_kwds : dict, optional
+        Additional keyword arguments to pass to the fit line plot.
+
+    Returns
+    -------
+    ax : matplotlib.axes.Axes
+        The axes with the Moran Scatterplot.
+
+    Raises
+    ------
+    ImportError
+        If matplotlib is not installed.
+    """
+
+    try:
+        from matplotlib import pyplot as plt
+    except ImportError as err:
+        raise ImportError(
+            "matplotlib library must be installed to use the scatterplot feature"
+        ) from err
+
+    # to set default as an empty dictionary that is later filled with defaults
+    if scatter_kwds is None:
+        scatter_kwds = dict()
+    if fitline_kwds is None:
+        fitline_kwds = dict()
+
+    if crit_value is not None:
+        labels = _get_cluster_labels(moran, crit_value)
+        # TODO: allow customization of colors in here and in plot and explore
+        # TODO: in a way to keep them easily synced
+        colors5_mpl = {
+            "High-High": "#d7191c",
+            "Low-High": "#89cff0",
+            "Low-Low": "#2c7bb6",
+            "High-Low": "#fdae61",
+            "Insignificant": "lightgrey",
+        }
+        colors5 = [colors5_mpl[i] for i in labels]  # for mpl
+
+    # define customization
+    scatter_kwds.setdefault("alpha", 0.6)
+    fitline_kwds.setdefault("alpha", 0.9)
+
+    if ax is None:
+        _, ax = plt.subplots()
+
+    ax.set_title("Moran Scatterplot")
+
+    if bivariate:
+        x = moran.zx
+        lag = lag_spatial(moran.w, moran.zy)
+        ax.set_xlabel("Attribute X")
+        ax.set_ylabel("Spatial Lag of Y")
+    else:
+        x = moran.z
+        lag = lag_spatial(moran.w, moran.z)
+        ax.set_xlabel("Attribute")
+        ax.set_ylabel("Spatial Lag")
+
+    fit = stats.linregress(
+        x,
+        lag,
+    )
+    # v- and hlines
+    ax.axvline(0, alpha=0.5, color="k", linestyle="--")
+    ax.axhline(0, alpha=0.5, color="k", linestyle="--")
+    if crit_value is not None:
+        fitline_kwds.setdefault("color", "k")
+        scatter_kwds.setdefault("c", colors5)
+        ax.plot(x, fit.intercept + fit.slope * x, **fitline_kwds)
+        ax.scatter(x, lag, **scatter_kwds)
+    else:
+        scatter_kwds.setdefault("color", "#bababa")
+        fitline_kwds.setdefault("color", "#d6604d")
+        ax.plot(x, fit.intercept + fit.slope * x, **fitline_kwds)
+        ax.scatter(x, lag, **scatter_kwds)
+
+    ax.set_aspect("equal")
+
+    return ax
+
+
+def _simulation_plot(
+    moran, ax=None, legend=False, bivariate=False, fitline_kwds=None, **kwargs
+):
+    try:
+        import seaborn as sns
+        from matplotlib import pyplot as plt
+    except ImportError as err:
+        raise ImportError(
+            "matplotlib and seaborn must be installed to plot the simulation."
+        ) from err
+    # to set default as an empty dictionary that is later filled with defaults
+    if fitline_kwds is None:
+        fitline_kwds = dict()
+
+    if ax is None:
+        _, ax = plt.subplots()
+
+    # plot distribution
+    shade = kwargs.pop("shade", True)
+    color = kwargs.pop("color", "#bababa")
+    sns.kdeplot(
+        moran.sim,
+        fill=shade,
+        color=color,
+        ax=ax,
+        label="Distribution of simulated Is",
+        **kwargs,
+    )
+
+    exp = moran.EI_sim if bivariate else moran.EI
+
+    # customize plot
+    fitline_kwds.setdefault("color", "#d6604d")
+    ax.vlines(moran.I, 0, 1, **fitline_kwds, label="Moran's I")
+    ax.vlines(exp, 0, 1, label="Expected I")
+    ax.set_title("Reference Distribution")
+    ax.set_xlabel(f"Moran's I: {moran.I:.2f}")
+
+    if legend:
+        ax.legend()
+    return ax
+
+
+def _plot_combination(
+    moran_loc,
+    gdf,
+    attribute,
+    crit_value=0.05,
+    region_column=None,
+    mask=None,
+    mask_color="#636363",
+    quadrant=None,
+    legend=True,
+    scheme="Quantiles",
+    cmap="YlGnBu",
+    figsize=(15, 4),
+    scatter_kwds=None,
+    fitline_kwds=None,
+    legend_kwds=None,
+):
+    """
+    Produce three-plot visualisation of Moran Scatteprlot, LISA cluster
+    and Choropleth maps, with Local Moran region and quadrant masking
+
+    Parameters
+    ----------
+    moran_loc : esda.moran.Moran_Local or Moran_Local_BV instance
+        Values of Moran's Local Autocorrelation Statistic
+    gdf : geopandas dataframe
+        The Dataframe containing information to plot the two maps.
+    attribute : str
+        Column name of attribute which should be depicted in Choropleth map.
+    p : float, optional
+        The p-value threshold for significance. Points and polygons will
+        be colored by significance. Default = 0.05.
+    region_column: string, optional
+        Column name containing mask region of interest. Default = None
+    mask: str, float, int, optional
+        Identifier or name of the region to highlight. Default = None
+        Use the same dtype to specifiy as in original dataset.
+    mask_color: str, optional
+        Color of mask. Default = '#636363'
+    quadrant : int, optional
+        Quadrant 1-4 in scatterplot masking values in LISA cluster and
+        Choropleth maps. Default = None
+    figsize: tuple, optional
+        W, h of figure. Default = (15,4)
+    legend: boolean, optional
+        If True, legend for maps will be depicted. Default = True
+    scheme: str, optional
+        Name of PySAL classifier to be used. Default = 'Quantiles'
+    cmap: str, optional
+        Name of matplotlib colormap used for plotting the Choropleth.
+        Default = 'YlGnBu'
+    scatter_kwds : keyword arguments, optional
+        Keywords used for creating and designing the scatter points.
+        Default =None.
+    fitline_kwds : keyword arguments, optional
+        Keywords used for creating and designing the moran fitline
+        in the scatterplot. Default =None.
+    legend_kwds : dict
+        Keyword arguments passed to geopandas.GeodataFrame.plot ``legend_kwds`` allowing
+        repositioning of the legend in LISA cluster plot and choropleth.
+
+    Returns
+    -------
+    axs : array of Matplotlib axes
+    """
+    try:
+        from matplotlib import patches
+        from matplotlib import pyplot as plt
+
+    except ImportError as err:
+        raise ImportError(
+            "matplotlib library must be installed to use the scatterplot feature"
+        ) from err
+
+    _, axs = plt.subplots(
+        1, 3, figsize=figsize, subplot_kw={"aspect": "equal", "adjustable": "datalim"}
+    )
+    # Moran Scatterplot
+    moran_loc.plot_scatter(
+        crit_value=crit_value,
+        ax=axs[0],
+        scatter_kwds=scatter_kwds,
+        fitline_kwds=fitline_kwds,
+    )
+
+    # Lisa cluster map
+    moran_loc.plot(
+        gdf,
+        crit_value=crit_value,
+        ax=axs[1],
+        legend=legend,
+        legend_kwds=legend_kwds,
+    )
+
+    # Choropleth for attribute
+    gdf.plot(
+        column=attribute,
+        scheme=scheme,
+        cmap=cmap,
+        legend=legend,
+        legend_kwds=legend_kwds,
+        ax=axs[2],
+        alpha=1,
+    )
+    axs[2].set_axis_off()
+    axs[2].set_aspect("equal")
+
+    # MASKING QUADRANT VALUES
+    if quadrant is not None:
+        # Quadrant masking in Scatterplot
+        mask_angles = {1: 0, 2: 90, 3: 180, 4: 270}  # rectangle angles
+        # We don't want to change the axis data limits, so use the current ones
+        xmin, xmax = axs[0].get_xlim()
+        ymin, ymax = axs[0].get_ylim()
+        # We are rotating, so we start from 0 degrees and
+        # figured out the right dimensions for the rectangles for other angles
+        mask_width = {1: abs(xmax), 2: abs(ymax), 3: abs(xmin), 4: abs(ymin)}
+        mask_height = {1: abs(ymax), 2: abs(xmin), 3: abs(ymin), 4: abs(xmax)}
+        axs[0].add_patch(
+            patches.Rectangle(
+                (0, 0),
+                width=mask_width[quadrant],
+                height=mask_height[quadrant],
+                angle=mask_angles[quadrant],
+                color="#E5E5E5",
+                zorder=-1,
+                alpha=0.8,
+            )
+        )
+        # quadrant selection in maps
+        non_quadrant = ~(moran_loc.q == quadrant)
+        mask_quadrant = gdf[non_quadrant]
+        df_quadrant = gdf.iloc[~non_quadrant]
+        union2 = df_quadrant.dissolve().boundary
+
+        # LISA Cluster mask and cluster boundary
+        mask_quadrant.plot(
+            scheme=scheme,
+            color="white",
+            ax=axs[1],
+            alpha=0.7,
+            zorder=1,
+        )
+        union2.plot(linewidth=1, ax=axs[1], color="#E5E5E5")
+
+        # CHOROPLETH MASK
+        mask_quadrant.plot(
+            scheme=scheme,
+            color="white",
+            ax=axs[2],
+            alpha=0.7,
+            zorder=1,
+        )
+        union2.plot(linewidth=1, ax=axs[2], color="#E5E5E5")
+
+    # REGION MASKING
+    if region_column is not None:
+        # masking inside axs[0] or Moran Scatterplot
+        # enforce the same dtype of list and mask
+        if not isinstance(mask[0], type(gdf[region_column].iloc[0])):
+            warn(
+                "Values in `mask` are not the same dtype as"
+                + " values in `region_column`. Converting `mask` values"
+                + " to dtype of first observation in region_column.",
+                stacklevel=3,
+            )
+            data_type = type(gdf[region_column][0].item())
+            mask = list(map(data_type, mask))
+
+        ix = gdf[region_column].isin(mask)
+
+        if not ix.any():
+            raise ValueError(
+                f"Specified values {mask} in `mask` not in `region_column`"
+            )
+
+        df_mask = gdf[ix]
+        x_mask = moran_loc.z[ix]
+        y_mask = lag_spatial(moran_loc.w, moran_loc.z)[ix]
+        axs[0].plot(
+            x_mask,
+            y_mask,
+            color=mask_color,
+            marker="o",
+            markersize=14,
+            alpha=0.8,
+            linestyle="None",
+            zorder=-1,
+        )
+
+        # masking inside axs[1] or Lisa cluster map
+        union = df_mask.dissolve().boundary
+        union.plot(linewidth=2, ax=axs[1], color=mask_color)
+
+        # masking inside axs[2] or Chloropleth
+        union.plot(linewidth=2, ax=axs[2], color=mask_color)
+
+    axs[0].spines[["right", "top"]].set_visible(False)
+    axs[1].set_axis_off()
+
+    return axs
+
+
 # --------------------------------------------------------------
 # Conditional Randomization Moment Estimators
 # --------------------------------------------------------------
